psetupsvc

package
v0.15.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 2, 2023 License: AGPL-3.0 Imports: 13 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var ErrInvalidStepIndex = errors.New("invalid step index")
var (
	ErrProviderSetupNotFound = errors.New("provider setup not found")
)

Functions

This section is empty.

Types

type InvalidConfigFieldError

type InvalidConfigFieldError struct {
	Key string
}

InvalidConfigFieldError is returned if the user attempts to set config field values which don't exist on the provider.

func (InvalidConfigFieldError) Error

func (e InvalidConfigFieldError) Error() string

type Service

type Service struct {
	DB               ddb.Storage
	DeploymentSuffix string
	TemplateData     psetup.TemplateData
}

func (*Service) CompleteStep

func (s *Service) CompleteStep(ctx context.Context, setupID string, stepIndex int, body types.ProviderSetupStepCompleteRequest) (*providersetup.Setup, error)

func (*Service) Create

func (s *Service) Create(ctx context.Context, providerType string, existingProviders deploy.ProviderMap, r providerregistry.ProviderRegistry) (*providersetup.Setup, error)

Create a new provider setup. Checks that the provider type matches one in our registry.

Jump to